SystemOrganization addCategory: #'Metacello-Platform'!

!MCFtpRepository methodsFor: '*metacello-platform' stamp: 'dkh 6/12/2012 10:18:46.076'!
asRepositorySpecFor: aMetacelloMCProject
	| dir |
	dir := directory.
	(directory at: 1) = $/
		ifFalse: [ dir := '/', dir ].
	^(aMetacelloMCProject repositorySpec)
		description:  'ftp://', host, dir;
	 	type: 'ftp';
		username: user;
		password: password;
		yourself! !

!BlockContext methodsFor: '*metacello-platform' stamp: 'dkh 6/12/2012 10:18:46.076'!
setAuthorInMetacelloConfig: aMetacelloConfig

	aMetacelloConfig setAuthorWithBlock: self! !

!BlockContext methodsFor: '*metacello-platform' stamp: 'dkh 6/12/2012 10:18:46.076'!
setBlessingInMetacelloConfig: aMetacelloConfig

	aMetacelloConfig setBlessingWithBlock: self! !

!BlockContext methodsFor: '*metacello-platform' stamp: 'dkh 6/12/2012 10:18:46.076'!
setDescriptionInMetacelloConfig: aMetacelloConfig

	aMetacelloConfig setDescriptionWithBlock: self! !

!BlockContext methodsFor: '*metacello-platform' stamp: 'dkh 6/12/2012 10:18:46.076'!
setPackage: aString withInMetacelloConfig: aMetacelloConfig

	aMetacelloConfig setPackage: aString withBlock: self! !

!BlockContext methodsFor: '*metacello-platform' stamp: 'dkh 6/12/2012 10:18:46.076'!
setProject: aString withInMetacelloConfig: aMetacelloConfig

	aMetacelloConfig setProject: aString withBlock: self! !

!BlockContext methodsFor: '*metacello-platform' stamp: 'dkh 6/12/2012 10:18:46.076'!
setTimestampInMetacelloConfig: aMetacelloConfig

	aMetacelloConfig setTimestampWithBlock: self! !

!BlockContext methodsFor: '*metacello-platform' stamp: 'dkh 6/12/2012 10:18:46.076'!
valueSupplyingMetacelloAnswers: aListOfPairs
	"evaluate the block using a list of questions / answers that might be called upon to
	automatically respond to Object>>confirm: or FillInTheBlank requests"

	^ [self value] 
		on: ProvideAnswerNotification
		do: 
			[:notify | | answer caption |
			
			caption := notify messageText withSeparatorsCompacted. "to remove new lines"
			answer := aListOfPairs
				detect: 
					[:each | caption = each first or:
						[(caption includesSubstring: each first caseSensitive: false) or:
						[(each first match: caption) or:
						[(String includesSelector: #matchesRegex:) and: 
						[ [ caption matchesRegex: each first ] on: Error do: [:ignored | false ]]]]]]
					ifNone: [nil].
			answer
				ifNotNil: [notify resume: answer second]
				ifNil: 
					[ | outerAnswer |
					outerAnswer := ProvideAnswerNotification signal: notify messageText.
					outerAnswer 
						ifNil: [notify resume] 
						ifNotNil: [notify resume: outerAnswer]]]! !

!MCDictionaryRepository methodsFor: '*metacello-platform' stamp: 'dkh 6/12/2012 10:18:46.076'!
possiblyNewerVersionsOfAnyOf: versionNames 

	^#()! !

MetacelloPlatform subclass: #MetacelloSqueakPlatform
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Metacello-Platform'!

!MetacelloSqueakPlatform class methodsFor: 'initialize-release' stamp: 'dkh 6/12/2012 10:18:46.076'!
initialize
  self select

! !

!MetacelloSqueakPlatform methodsFor: 'utilities' stamp: 'dkh 6/12/2012 10:18:46.076'!
authorName

	^Utilities authorInitials! !

!MetacelloSqueakPlatform methodsFor: 'utilities' stamp: 'dkh 6/12/2012 10:18:46.076'!
authorName: aString

	^Utilities setAuthorInitials: aString! !

!MetacelloSqueakPlatform methodsFor: 'notification' stamp: 'dkh 6/12/2012 10:18:46.076'!
collection: aCollection do: aBlock displaying: aString

	self bypassProgressBars ifTrue: [ ^super collection: aCollection do: aBlock displaying: aString ].
	aCollection 
		do: aBlock
		displayingProgress: aString! !

!MetacelloSqueakPlatform methodsFor: 'reflection' stamp: 'dkh 6/12/2012 10:18:46.076'!
copyClass: oldClass as: newName inCategory: newCategoryName
	| copysName class newDefinition |
	copysName := newName asSymbol.
	copysName = oldClass name
		ifTrue: [ ^ oldClass ].
	(Smalltalk includesKey: copysName)
		ifTrue: [ ^ self error: copysName , ' already exists' ].
	newDefinition := oldClass definition copyReplaceAll: '#' , oldClass name asString with: '#' , copysName asString printString.
	newDefinition := newDefinition
		copyReplaceAll: 'category: ' , (SystemOrganization categoryOfElement: oldClass name) asString printString
		with: 'category: ' , newCategoryName printString.
	class := Compiler evaluate: newDefinition logged: true.
	class class instanceVariableNames: oldClass class instanceVariablesString.
	class copyAllCategoriesFrom: oldClass.
	class class copyAllCategoriesFrom: oldClass class.
	class category: newCategoryName.
	^ class! !

!MetacelloSqueakPlatform methodsFor: 'repository creation' stamp: 'dkh 6/12/2012 10:18:46.076'!
createRepository: aRepositorySpec 
	| type |
	type := aRepositorySpec type.
	type = 'ftp'
		ifTrue: [| description headerSize index host directory |
			description := aRepositorySpec description.
			headerSize := 'ftp://' size.
			index := description indexOf: $/ startingAt: headerSize + 1.
			host := description copyFrom: headerSize + 1 to: index - 1.
			directory := description copyFrom: index + 1 to: description size.
			^ MCFtpRepository
				host: host
				directory: directory
				user: aRepositorySpec username
				password: aRepositorySpec password].
	^ super createRepository: aRepositorySpec! !

!MetacelloSqueakPlatform methodsFor: 'attributes' stamp: 'dkh 3/21/2013 14:01'!
defaultPlatformAttributes
	| attributes versionString |
	attributes := OrderedCollection with: #squeakCommon with: #squeak.
	Smalltalk
		at: #SystemVersion
		ifPresent: [:cl | 
			versionString := cl current version.
			(versionString beginsWith: 'Squeak3.10')
				ifTrue: [attributes add: #'squeak3.10.x'].
			(versionString beginsWith: 'Squeak4')
				ifTrue: [attributes add: #'squeak4.x'.
					(versionString beginsWith: 'Squeak4.1')
						ifTrue: [attributes add: #'squeak4.1.x']
						ifFalse: [(versionString beginsWith: 'Squeak4.2')
								ifTrue: [attributes add: #'squeak4.2.x']
								ifFalse: [(versionString beginsWith: 'Squeak4.3')
									ifTrue: [attributes add: #'squeak4.3.x']
									ifFalse: [(versionString beginsWith: 'Squeak4.4')
										ifTrue: [attributes add: #'squeak4.4.x']
											ifFalse: [(versionString beginsWith: 'Squeak4.5')
												ifTrue: [attributes add: #'squeak4.5.x']]]]]]].
	^ attributes! !

!MetacelloSqueakPlatform methodsFor: 'as yet unclassified' stamp: 'tfel 7/29/2014 14:39'!
directoryFromPath: adirectoryPath relativeTo: anotherDirectoryPath
	"Get a handle on the following path: anotherDirectoryPath/adirectoryPath"
	| path |
      "remove trailing slash - required for Windows compat"
      path := adirectoryPath last = $/
		ifTrue: [adirectoryPath allButLast] ifFalse: [adirectoryPath].
	^ anotherDirectoryPath directoryNamed: path! !

!MetacelloSqueakPlatform methodsFor: 'notification' stamp: 'dkh 6/12/2012 10:18:46.076'!
do: aBlock displaying: aString

	self bypassProgressBars ifTrue: [ ^super do: aBlock displaying: aString ].
	aString
		displayProgressAt: Sensor cursorPoint
		from: 0 to: 2
		during: [:bar |
			bar value: 1.
			aBlock value.
			bar value: 2 ]! !

!MetacelloSqueakPlatform methodsFor: 'github support' stamp: 'tfel 7/29/2014 13:53'!
downloadFile: url to: outputFileName
    "download from <url> into <outputFileName>"

    | archive zipfile response |
    response := WebClient httpGet: url.
    archive := ZipArchive new.
    zipfile := FileDirectory on: (FileDirectory default fullPathFor: outputFileName).
    zipfile containingDirectory assureExistence.
    response
         streamTo: ((zipfile containingDirectory forceNewFileNamed: zipfile localName) binary; yourself)
         size: response contentLength progress: nil.
    zipfile containingDirectory
		readOnlyFileNamed: zipfile localName
		do: [:fileStream | archive readFrom: fileStream].
    ^ archive
! !

!MetacelloSqueakPlatform methodsFor: 'github support' stamp: 'tfel 7/29/2014 14:42'!
extractRepositoryFrom: zipFile to: directory
    "unzip <zipFile> into <directory>"
    ZipArchive new
        readFrom: zipFile;
        extractAllTo: (FileDirectory on: directory) informing: nil overwrite: true.! !

!MetacelloSqueakPlatform methodsFor: 'repository creation' stamp: 'dkh 6/12/2012 10:18:46.076'!
extractTypeFromDescription: description 
	(description beginsWith: 'ftp://')
		ifTrue: [^ 'ftp'].
	^ super extractTypeFromDescription: description! !

!MetacelloSqueakPlatform methodsFor: 'reflection' stamp: 'dkh 6/12/2012 10:18:46.076'!
globalNamed: globalName

	^Smalltalk at: globalName! !

!MetacelloSqueakPlatform methodsFor: 'reflection' stamp: 'dkh 6/12/2012 10:18:46.076'!
globalNamed: globalName ifAbsent: absentBlock

	^Smalltalk at: globalName ifAbsent: absentBlock! !

!MetacelloSqueakPlatform methodsFor: 'utilities' stamp: 'dkh 6/12/2012 10:18:46.076'!
timestamp
	^Date today mmddyyyy, ' ',	
		((String streamContents: [:s | Time now print24: true on: s]) copyFrom: 1 to: 5)! !

!FileDirectory methodsFor: '*metacello-platform' stamp: 'dkh 2/25/2013 17:18'!
asRepositorySpecFor: aMetacelloMCProject
  ""

  ^ aMetacelloMCProject repositorySpec
    description: self fullName;
    type: 'directory';
    yourself
! !
MetacelloSqueakPlatform initialize!
